@@ -20,7 +20,7 @@ PANEL_DASHBOARD = 'project'
 PANEL_GROUP = 'database'
 
 # Python panel class of the PANEL to be added.
-ADD_PANEL = ('trove_dashboard.content.databases.panel.Databases')
+ADD_PANEL = 'trove_dashboard.content.databases.panel.Databases'
 
 ADD_INSTALLED_APPS = ["trove_dashboard", ]
 
